Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(109)

Unified Diff: pkg/compiler/lib/src/common_elements.dart

Issue 2859133003: Find native classes with mixins in NativeClassFinder (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/compiler/lib/src/js_backend/backend.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/common_elements.dart
diff --git a/pkg/compiler/lib/src/common_elements.dart b/pkg/compiler/lib/src/common_elements.dart
index 1e238d0b009c77a03ee77eb06a80fa891caa4df2..9bce67b5318ab88182fba5b3eb5fe21baf5b0b32 100644
--- a/pkg/compiler/lib/src/common_elements.dart
+++ b/pkg/compiler/lib/src/common_elements.dart
@@ -1197,15 +1197,19 @@ abstract class ElementEnvironment {
/// Returns the superclass of [cls].
///
/// Unnamed mixin applications are included, for instance for these classes
///
/// class S {}
/// class M {}
/// class C extends S with M {}
///
/// the result of `getSuperClass(C)` is the unnamed mixin application
- /// typically named `S+M` and `getSuperClass(S+M)` is `S`.
- ClassEntity getSuperClass(ClassEntity cls);
+ /// typically named `S+M` and `getSuperClass(S+M)` is `S`, whereas
+ /// the result of `getSuperClass(C, skipUnnamedMixinApplications: false)` is
+ /// `S`.
+ ClassEntity getSuperClass(ClassEntity cls,
+ {bool skipUnnamedMixinApplications: false});
void forEachSupertype(ClassEntity cls, void f(InterfaceType supertype));
« no previous file with comments | « no previous file | pkg/compiler/lib/src/js_backend/backend.dart » ('j') | no next file with comments »
@@ -1197,15 +1197,19 @@ abstract class ElementEnvironment {
/// Returns the superclass of [cls].
///
- /// Unnamed mixin applications are included, for instance for these classes
+ /// If [skipUnnamedMixinApplications] is `true`, unnamed mixin applications
+ /// are excluded, for instance for these classes
///
/// class S {}

Powered by Google App Engine
This is Rietveld 408576698